@@ -39,6 +39,7 @@ sub new {
                 footnote_symbol => '',
                 footnote_index => '',
                 anchors => [],
+                language => '',
                };
     my %provided;
     foreach my $accessor (keys %$self) {
@@ -61,6 +62,16 @@ sub new {
     bless $self, $class;
 }
 
+=item language
+
+Accessor to the language attribute
+
+=cut
+
+sub language {
+    shift->{language};
+}
+
 =item rawline
 
 Accessor to the raw input line
